import unittest
from ybc_player import *


class MyTestCase(unittest.TestCase):
    def test_play(self):
        play('test.wav')

    def test_play_ParameterTypeError(self):
        with self.assertRaisesRegex(ParameterTypeError, "^参数类型错误 : 调用play方法时，'filename'参数类型错误。$"):
            play(1)

    def test_play_ParameterValueError(self):
        with self.assertRaisesRegex(ParameterValueError, "^参数数值错误 : 调用play方法时，'filename'参数不在允许范围内。$"):
            play('')


if __name__ == '__main__':
    unittest.main()


# coding=utf-8
import os
import sys
from ybc_exception import *


def play(filename=''):
    """
    功能：播放filename指定的音频、视频文件。

    参数 filename 是当前目录下期望播放的音频、视频文件的名字，

    返回：无。
    """
    error_msg = "'filename'"
    # 参数类型正确性判断
    if not isinstance(filename, str):
        raise ParameterTypeError(function_name=sys._getframe().f_code.co_name, error_msg=error_msg)

    # 参数取值正确性判断
    if not filename:
        raise ParameterValueError(function_name=sys._getframe().f_code.co_name, error_msg=error_msg)
    try:
        filepath = os.path.abspath(filename)
        os.system(filepath)
    except Exception as e:
        raise InternalError(e, 'ybc_player')


def main():
    play('test.wav')


if __name__ == '__main__':
    main()



#!/usr/bin/env python

from distutils.core import setup

setup(name='ybc_player',
      version='1.0.1',
      description='Play audio file.',
      long_description='Play the audio file in current dictionary',
      author='lijz01',
      author_email='lijz01@fenbi.com',
      keywords=['python', 'play', 'audio'],
      url='http://pip.zhenguanyu.com/',
      packages=['ybc_player'],
      package_data={'ybc_player': ['html/*', 'test.wav', '__init__.py', 'ybc_player.py', 'ybc_player_unitest.py']},
      license='MIT',
      install_requires=['ybc_exception']
     )